```{toctree}
:maxdepth: 2
:titlesonly:
:caption: General
:hidden:

Readme <self>
Contribute <misc/contributing_link>
Known Issues <known_issues>
Changelog <misc/changelog_link>
Github <https://github.com/emdgroup/baybe/>
Contributors <misc/contributors_link>
License <misc/license_link>
```

```{include} ../README.md
:relative-docs: docs/
```

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:
   :caption: Package

   baybe
```

```{toctree}
:maxdepth: 2
:titlesonly:
:hidden:

User Guide <userguide/userguide>
Examples <examples/examples>
```

# Indices and Tables

- {ref}`modindex`
